Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'app/models/programming_language.rb')
-rw-r--r--app/models/programming_language.rb7
1 files changed, 4 insertions, 3 deletions
diff --git a/app/models/programming_language.rb b/app/models/programming_language.rb
index 375fbe9b5a9..06e3034e56a 100644
--- a/app/models/programming_language.rb
+++ b/app/models/programming_language.rb
@@ -4,9 +4,10 @@ class ProgrammingLanguage < ApplicationRecord
validates :name, presence: true
validates :color, allow_blank: false, color: true
# Returns all programming languages which match the given name (case
# insensitively).
- scope :with_name_case_insensitive, ->(name) do
- where(arel_table[:name].matches(sanitize_sql_like(name)))
+ scope :with_name_case_insensitive, ->(*names) do
+ sanitized_names = names.map(&method(:sanitize_sql_like))
+ where(arel_table[:name].matches_any(sanitized_names))
end
end
@@ -4,9 +4,10 @@ class ProgrammingLanguage < ApplicationRecord
validates :name, presence: true
validates :color, allow_blank: false, color: true
- # Returns all programming languages which match the given name (case
+ # Returns all programming languages which match any of the given names (case
# insensitively).